%This file contains the main keywords that are needed for model
%configuration. This script runs in KADMOS_Path routine
%-----------------------------------------------------------------------
name_file               = ['run_001'];       %name of file
%Crystal size ----------------------------------------------------------
Lr                      = [10,20,50];        %Grainsize in microns (ROW)
%Geometry employed ----------------------------------------------------
ndim_a                  = [3,3,3];           %Geometry E[1,2,3]    (ROW)
%Initial Ages (in Myr) --------------------------------------------------
Age0                    = [0,0,0];           %Initial Ages in Myr  (ROW)
%Define Mineral System----------------------------------------------------
Min_Sys                 = [{'Muscovite1'},{'Muscovite1'},{'Muscovite1'}];
%Create P-T-t data-------------------------------------------------------
tlim                    = 50;                %Limit on time in Myr
T0                      = 600;               %Starting T (in C)
P0                      = 2000;              %Initial Pressure (MPa)
Pmin                    = 10;                %Final pressure   (MPa; for lin-P-T)
Tmin                    = 25;                %Final T (C)  for all CR models
SCR                     = 50;                %Absolute Cooling Rate (C/Myr)
[Pres_A,TempK_A,time_A] = make_PTtpath('lin-CR',T0, SCR,P0,Pmin,Tmin,tlim);
%================================================================================
%======================PLEASE DO NOT MODIFY BELOW THIS POINT=====================
%================================================================================
Pres_a                  = repmat(Pres_A,length(Lr),1)';   %P array is ndd * Npath
TempK_a                 = repmat(TempK_A,length(Lr),1)';  %T array is ndd * Npath
time_a                  = repmat(time_A,length(Lr),1)';   %t array is ndd * Npath
%----------------------------------------------------------------
clearvars -except Lr ndim_a Age0 Min_Sys Pres_a TempK_a time_a tlim Tmin Pmin T0 name_file

%Functions Used ===========================================================
function [Pres_a,TempK_a,time_a] = make_PTtpath(type_path,T0,SCR,P0,Pmin,Tmin,tlim0)
%options lin-CR, asy-CR, iso-T, lin-P-T, custom (loaded from PTt_params.dat)
%T0    : Starting T (in C)
%SCR   : cooling rate (for lin-CR or asy-CR)
%P0    : Starting P (MPa)
%Pmin  : Minimum pressure - linear decrease assumed
%Tmin  : low-T limit for the path calculation (not real closure T)
%T is in C then output in K
%P is in MPa
%time is in Myr
nres   = 1000;
time_a = linspace(0,tlim0,nres);
if strcmp(type_path,'lin-CR')==1
    T      = T0 - SCR*time_a;
    Pres_a = P0*ones(size(time_a));
elseif strcmp(type_path,'asy-CR')==1
    T      = T0./(1+SCR.*time_a./T0);
    Pres_a = P0*ones(size(time_a));
elseif strcmp(type_path,'lin-P-T')==1
    T      = linspace(T0,Tmin);
    Pres_a = linspace(P0,Pmin);
    time_a = linspace(0,tlim0);
elseif strcmp(type_path,'iso-T')==1
    %inputs T0 (C), duration in Myr
    time_a = linspace(0,tlim0);
    T      = T0*ones(size(time_a));
    Pres_a = P0*ones(size(time_a));
elseif strcmp(type_path,'loaded')
    load PTt_params.dat
    [n1 n2] = size(PTt_params);
    if n1 == 3 && n2 ~=3
        Pres_a  = PTt_params(1,:);
        TempC_a = PTt_params(2,:);
        time_a  = PTt_params(3,:);
    elseif n2 == 3 && n2 ~= 3
        Pres_a  = PTt_params(:,1);
        TempC_a = PTt_params(:,2);
        time_a  = PTt_params(:,3);
    else
        disp('PTt_params must be a 3xN or a Nx3 matrix (for P,T & t arrays)')
        error('resize PTt matrix as 3xN or Nx3 matrix')
    end
    T = TempC_a;
else
    error('Not recognized type of path')
end
T(T<Tmin)           = Tmin;
Pres_a(Pres_a<Pmin) = Pmin;
TempK_a = T+273.15;
end